Share Apache Arrow objects between Python and R using rpy2.

![Python package](https://github.com/rpy2/rpy2-arrow/workflows/Python%20package/badge.svg)

This is still work in progress, but there is:

- [HTML doc](https://rpy2.github.io/rpy2-arrow/version/main/html/)
- [demo notebooks](doc/notebooks/).

To install:

```bash
pip install rpy2-arrow
```
